# eis-accounting
The EMIL AccountingService API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.accounting
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import eis.accounting
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.accounting
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.accounting
from pprint import pprint
from eis.accounting.api import booking_processes_api
from eis.accounting.model.create_booking_process_request_dto import CreateBookingProcessRequestDto
from eis.accounting.model.create_booking_process_response_class import CreateBookingProcessResponseClass
from eis.accounting.model.list_booking_process_response_class import ListBookingProcessResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.accounting.Configuration(
    host = "https://apiv2.emil.de"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Bearer is automatically handled with exported environment variables. However, you
# can manuallay configure Bearer authorization (JWT): bearer
configuration = eis.accounting.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# After manual token becomes invalid, the SDK will default to re-login automatically
# with environment variable credentials.


# Enter a context with an instance of the API client
with eis.accounting.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = booking_processes_api.BookingProcessesApi(api_client)
    create_booking_process_request_dto = CreateBookingProcessRequestDto(
        policy_number="POL_700001",
        status="paid",
        booking_process_type="recurringInvoice",
        custom_fields={},
        booking_entries=[
            CreateBookingEntryRequestDto(
                booking_date=dateutil_parser('2024-06-24T10:12:46.493Z'),
                description="Invoice payment for policy 010101489/V",
                policy_number="POL_700001",
                entity_name="invoice",
                entity_number="INV2405840",
                currency="EUR",
                amount=100,
                booking_process_id=12345,
                custom_fields={},
                financial_transactions=[
                    FinancialTransactionDataDto(
                        financial_account_number="40010001",
                        amount=100,
                        debit_credit="CREDIT",
                        partner_number="1234567890",
                        partner_group="Partner Group",
                        policy_number="1234567890",
                        custom_fields={},
                        description="Monthly premium payment for policy 1234567890",
                    ),
                ],
            ),
        ],
    ) # CreateBookingProcessRequestDto | 
    authorization = "Authorization_example" # str | Bearer Token: provided by the login endpoint under the name accessToken. (optional)

    try:
        # Create the booking process
        api_response = api_instance.create_booking_process(create_booking_process_request_dto, authorization=authorization)
        pprint(api_response)
    except eis.accounting.ApiException as e:
        print("Exception when calling BookingProcessesApi->create_booking_process: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BookingProcessesApi* | [**create_booking_process**](docs/BookingProcessesApi.md#create_booking_process) | **POST** /accountingservice/v1/booking-processes | Create the booking process
*BookingProcessesApi* | [**list_booking_processes**](docs/BookingProcessesApi.md#list_booking_processes) | **GET** /accountingservice/v1/booking-processes | List Booking processes
*FinancialAccountsApi* | [**create_financial_account**](docs/FinancialAccountsApi.md#create_financial_account) | **POST** /accountingservice/v1/financial-accounts | Create the Financial Account
*FinancialAccountsApi* | [**delete_financial_account**](docs/FinancialAccountsApi.md#delete_financial_account) | **DELETE** /accountingservice/v1/financial-accounts/{code} | Delete the Financial Account
*FinancialAccountsApi* | [**get_financial_account**](docs/FinancialAccountsApi.md#get_financial_account) | **GET** /accountingservice/v1/financial-accounts/{code} | Retrieve the Financial Account
*FinancialAccountsApi* | [**list_financial_accounts**](docs/FinancialAccountsApi.md#list_financial_accounts) | **GET** /accountingservice/v1/financial-accounts | List Financial Accounts
*HealthApi* | [**check**](docs/HealthApi.md#check) | **GET** /accountingservice/health | Health Check


## Documentation For Models

 - [BookingEntryClass](docs/BookingEntryClass.md)
 - [BookingProcessClass](docs/BookingProcessClass.md)
 - [CreateBookingEntryRequestDto](docs/CreateBookingEntryRequestDto.md)
 - [CreateBookingProcessRequestDto](docs/CreateBookingProcessRequestDto.md)
 - [CreateBookingProcessResponseClass](docs/CreateBookingProcessResponseClass.md)
 - [CreateFinancialAccountRequestDto](docs/CreateFinancialAccountRequestDto.md)
 - [CreateFinancialAccountResponseClass](docs/CreateFinancialAccountResponseClass.md)
 - [FinancialAccountClass](docs/FinancialAccountClass.md)
 - [FinancialTransactionClass](docs/FinancialTransactionClass.md)
 - [FinancialTransactionDataDto](docs/FinancialTransactionDataDto.md)
 - [GetFinancialAccountResponseClass](docs/GetFinancialAccountResponseClass.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [ListBookingProcessResponseClass](docs/ListBookingProcessResponseClass.md)
 - [ListFinancialAccountsResponseClass](docs/ListFinancialAccountsResponseClass.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.accounting.apis and eis.accounting.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.accounting.api.default_api import DefaultApi`
- `from eis.accounting.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.accounting
from eis.accounting.apis import *
from eis.accounting.models import *
```

